<template>
  <el-bus-crud v-bind="tableConfig" />
</template>

<script>
export default {
  data() {
    return {
      tableConfig: {
        url: 'flower/api/station/page',
        newUrl: 'flower/api/station/add',
        editUrl: 'flower/api/station/update',
        deleteUrl: 'flower/api/station/delete',
        deleteOnPath: true,
        deleteMethodType: 'post',
        operationAttrs: {
          width: 150,
          fixed: 'right',
        },
        columns: [
          { label: '集货站名称', prop: 'name', minWidth: 150, fixed: 'left' },
          { label: '集货站类型', prop: 'typeStr', minWidth: 100 },
          { label: '地址', prop: 'address', minWidth: 200 },
          { label: '运费(元)', prop: 'freight', minWidth: 100 },
          { label: '质检人员', prop: 'userNames', minWidth: 150 },
          { label: '联系人', prop: 'contactName', minWidth: 100 },
          { label: '联系方式', prop: 'contactTel', minWidth: 120 },
        ],
        searchForm: [
          {
            type: 'row',
            items: [{ label: '集货站名称', id: 'name', type: 'input' }],
          },
        ],
        form: [
          {
            label: '集货站名称：',
            id: 'name',
            type: 'input',
            rules: {
              required: true,
              message: '请输入集货站名称',
              trigger: 'blur',
            },
          },
          {
            label: '集货站类型：',
            id: 'type',
            type: 'bus-radio',
            el: {
              code: 'station_type',
              style: 'width:100%',
            },
            str: true,
            rules: { required: true, message: '请选择集货站类型' },
            on: {
              change: (e, updateForm) => {
                updateForm({ freight: undefined })
              },
            },
          },
          {
            label: '集货站地址：',
            id: 'address',
            type: 'input',
            rules: {
              required: true,
              message: '请输入集货站地址',
              trigger: 'blur',
            },
          },
          {
            label: '运费：',
            id: 'freight',
            type: 'input-number',
            el: {
              controls: false,
              min: 0,
              precision: 2,
            },
            unit: '元',
            rules: { required: true, message: '请输入运费', trigger: 'blur' },
            hidden: (row) => row.type !== '1',
          },
          {
            label: '质检人员：',
            id: 'userIds',
            type: 'bus-select',
            el: {
              interfaceUri: 'flower/api/user/list',
              extraQuery: {
                current: 1,
                size: 2000,
              },
              props: {
                label: 'nickName',
                value: 'id',
                dataPath: 'records',
              },
              filterable: true,
              multiple: true,
              style: 'width:100%',
            },
            inputFormat: (row) => {
              if ('userIds' in row) {
                return row.userIds ? row.userIds.split(',') : []
              }
            },
            outputFormat: (val) => {
              return Array.isArray(val) && val.length > 0 ? val.join(',') : null
            },
            str: true,
            strKey: 'userNames',
            rules: { required: true, message: '请选择质检人员' },
          },
          {
            label: '联系人：',
            id: 'contactName',
            type: 'input',
            rules: {
              required: true,
              message: '请输入联系人',
              trigger: 'blur',
            },
          },
          {
            label: '联系方式：',
            id: 'contactTel',
            type: 'input',
            rules: {
              required: true,
              message: '请输入联系方式',
              trigger: 'blur',
            },
          },
        ],
      },
    }
  },
  head() {
    return {
      title: '集货站管理',
    }
  },
}
</script>
